
# Slot: affects splicing of


holds between a molecular entity and an mRNA where the action or effect of the molecular entity impacts the splicing of the mRNA

URI: [biolink:affects_splicing_of](https://w3id.org/biolink/vocab/affects_splicing_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [Transcript](Transcript.md)

## Parents

 *  is_a: [affects](affects.md)

## Children

 *  [decreases splicing of](decreases_splicing_of.md)
 *  [increases splicing of](increases_splicing_of.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:affects_RNA_splicing |
| **Broad Mappings:** | | CTD:affects_splicing_of |

